pub enum Error {
JsonRpc(Error),
Json(Error),
DecodeHex(FromHexError),
Model(Box<dyn Error + Send + Sync + 'static>),
InvalidCookieFile,
InvalidUrl(String),
HexToArray(HexToArrayError),
Io(Error),
TryFromInt(TryFromIntError),
}Expand description
Errors that can occur when using the Bitcoin RPC client.
Variants
JsonRpc(Error)
JSON-RPC error from the server.
Json(Error)
JSON serialization/deserialization error.
DecodeHex(FromHexError)
Hex deserialization error.
Model(Box<dyn Error + Send + Sync + 'static>)
Error converting a version-specific RPC type into the model type.
InvalidCookieFile
Invalid or corrupted cookie file.
InvalidUrl(String)
The provided URL is syntactically incorrect.
HexToArray(HexToArrayError)
Hash parsing error.
Io(Error)
I/O error (e.g., reading cookie file, network issues).
TryFromInt(TryFromIntError)
Error when converting an integer type to a smaller type due to overflow.
Implementations
Sourceimpl Error
Extension methods for the client error type.
impl Error
Extension methods for the client error type.
Sourcepub fn is_not_found_error(&self) -> bool
pub fn is_not_found_error(&self) -> bool
Returns true if this is a “not found” error returned by bitcoind.
bitcoind returns error code -5 (RPC_INVALID_ADDRESS_OR_KEY)
whenever a requested block hash, transaction ID, address, or similar object
does not exist on the node.